@@ -53,7 +53,7 @@ class Host(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["HostProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[HostProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -314,7 +314,7 @@ class RosHost(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosHostProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosHostProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
